RoutingDslModule
play.routing.RoutingDslModule
class RoutingDslModule extends Module
A Play binding for the RoutingDsl API.
Attributes
- Graph
-
- Supertypes
Members list
Value members
Concrete methods
Get the bindings provided by this module.
Get the bindings provided by this module.
Implementations are strongly encouraged to do nothing in this method other than provide bindings. Startup should be handled in the constructors and/or providers bound in the returned bindings. Dependencies on other modules or components should be expressed through constructor arguments.
The configuration and environment a provided for the purpose of producing dynamic bindings, for example, if what gets bound depends on some configuration, this may be read to control that.
Value parameters
- configuration
-
The configuration
- environment
-
The environment
Attributes
- Returns
-
A sequence of bindings
- Definition Classes
Deprecated and Inherited methods
Create a binding key for the given class.
Create a binding key for the given class.
Attributes
- Deprecated
-
[Since version 2.7.0]Use play.inject.Module.bindClass instead if the Module is coded in Java. Scala modules can use play.api.inject.bind[T: ClassTag] - Inherited from:
- Module
In this article